summaryrefslogtreecommitdiffstats
path: root/khtml/misc/khtmllayout.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /khtml/misc/khtmllayout.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/misc/khtmllayout.h')
-rw-r--r--khtml/misc/khtmllayout.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/khtml/misc/khtmllayout.h b/khtml/misc/khtmllayout.h
index a67e7019e..e4fb531a1 100644
--- a/khtml/misc/khtmllayout.h
+++ b/khtml/misc/khtmllayout.h
@@ -18,22 +18,22 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
- This widget holds some useful definitions needed for tqlayouting Elements
+ This widget holds some useful definitions needed for layouting Elements
*/
#ifndef HTML_LAYOUT_H
#define HTML_LAYOUT_H
/*
* this namespace tqcontains definitions for various types needed for
* tqlayouting.
*/
namespace khtml
{
const int UNDEFINED = -1;
- // tqalignment
+ // alignment
enum VAlign { VNone=0, Bottom, VCenter, Top, Baseline };
enum HAlign { HDefault, Left, HCenter, Right, HNone = 0 };
@@ -103,7 +103,7 @@ namespace khtml
unsigned type : 3;
bool quirk : 1;
} l;
- TQ_UINT32 _length;
+ Q_UINT32 _length;
};
};
@@ -18,22 +18,22 @@
#define HTML_LAYOUT_H
/*
- * this namespace tqcontains definitions for various types needed for
- * tqlayouting.
+ * this namespace contains definitions for various types needed for
+ * layouting.
*/
namespace khtml